@@ -36,3 +36,11 @@ class EnumBase(Enum):
     @classmethod
     def dict(cls) -> dict:
         return dict([(key.name, key.value) for key in cls])
+
+    @classmethod
+    def array_dict(cls):
+        return [{key.name, key.value} for key in cls]
+
+    @classmethod
+    def array_dict_named_attrs(cls, name_key='id', name_value='text'):
+        return [{name_key: key.name, name_value: key.value} for key in cls]
