@@ -1,4 +1,5 @@
 import locale
+import time
 from datetime import date, datetime
 
 
@@ -23,12 +24,12 @@ def date_format(date_value: date):
     return date_value.strftime('%d/%m/%Y')
 
 
-def date_time(date_time: datetime):
-    return date_time.strftime('%d/%m/%Y %H:%M')
+def date_time(dt_time: datetime):
+    return dt_time.strftime('%d/%m/%Y %H:%M')
 
 
-def date_time_integer(date_time: datetime):
-    return date_time.strftime('%Y%m%d%H%M%S')
+def date_time_integer(dt_time: datetime):
+    return dt_time.strftime('%Y%m%d%H%M%S')
 
 
 def to_date(day, month, year):
@@ -40,3 +41,11 @@ def to_date(day, month, year):
 
 def datetime_now_integer():
     return date_time_integer(datetime.now())
+
+
+def to_time(str_time, pattern):
+    return time.strptime(str_time, pattern)
+
+
+def format_time(time_instance: time, pattern: str):
+    return time.strftime(pattern, time_instance)
