@@ -20,15 +20,19 @@ def is_ajax(request) -> bool:
         raise RuntimeError(e)
 
 
-def is_delete_method(request) -> bool:
+def is_delete(request) -> bool:
     try:
         return request.method == 'DELETE'
     except Exception as e:
         raise RuntimeError(e)
 
 
-def is_post_method(request) -> bool:
+def is_post(request) -> bool:
     try:
         return request.method == 'POST'
     except Exception:
         raise RuntimeError
+
+
+def is_post_ajax(request) -> bool:
+    return is_post(request) and is_ajax(request)
