@@ -1,14 +1,14 @@
-from core.settings import EMAIL_HOST_USER, EMAIL_HOST_PASSWORD, EMAIL_PORT, EMAIL_USE_TLS, EMAIL_HOST, APPLICATION_NAME
+from django.conf import settings
 
 
 class SmtpConf:
     def __init__(self):
-        self.__smtp = EMAIL_HOST,
-        self.port = EMAIL_PORT
-        self.use_tls = EMAIL_USE_TLS
-        self.user = EMAIL_HOST_USER
-        self.password = EMAIL_HOST_PASSWORD
-        self.app_name = APPLICATION_NAME
+        self.__smtp = settings.EMAIL_HOST,
+        self.port = settings.EMAIL_PORT
+        self.use_tls = settings.EMAIL_USE_TLS
+        self.user = settings.EMAIL_HOST_USER
+        self.password = settings.EMAIL_HOST_PASSWORD
+        self.app_name = settings.APPLICATION_NAME
 
     @property
     def smtp(self):
